## [0.4.14](https://github.com/l4rm4nd/PyADRecon-ADWS/compare/v0.4.13...v0.4.14) (2026-02-22)


### Bug Fixes

* rename finding ([e09d60f](https://github.com/l4rm4nd/PyADRecon-ADWS/commit/e09d60f8112b7ad2568af288deaeacfe5cba5a6d))

## [0.4.13](https://github.com/l4rm4nd/PyADRecon-ADWS/compare/v0.4.12...v0.4.13) (2026-02-22)


### Bug Fixes

* rework protected users group ([0e850bd](https://github.com/l4rm4nd/PyADRecon-ADWS/commit/0e850bdf0a30bf22f3f11ad60c87c8dc4f955b96))

## [0.4.12](https://github.com/l4rm4nd/PyADRecon-ADWS/compare/v0.4.11...v0.4.12) (2026-02-21)


### Bug Fixes

* add support for --generate-dashboard-from ([7e6eb2b](https://github.com/l4rm4nd/PyADRecon-ADWS/commit/7e6eb2b35dca62a0832a537f394d8dad42ed374f))

## [0.4.11](https://github.com/l4rm4nd/PyADRecon-ADWS/compare/v0.4.10...v0.4.11) (2026-02-21)


### Bug Fixes

* update footer ([26fae34](https://github.com/l4rm4nd/PyADRecon-ADWS/commit/26fae34a4a0fd921b752210a5879945a9f571569))

## [0.4.10](https://github.com/l4rm4nd/PyADRecon-ADWS/compare/v0.4.9...v0.4.10) (2026-02-21)


### Bug Fixes

* make dashboard more mobile friendly ([0233fc9](https://github.com/l4rm4nd/PyADRecon-ADWS/commit/0233fc98f96b0534ba75aae86e970e1c646e9321))

